@@ -4,21 +4,21 @@ function (data, constrained = FALSE, IRT.param = TRUE, Hessian = FALSE, start.va
     cl <- match.call()
     if ((!is.data.frame(data) & !is.matrix(data)) || ncol(data) == 1)
         stop("'data' must be either a numeric matrix or a data.frame, with at least two columns.\n")
-    X <- data.matrix(data)    
+    X <- data.matrix(data)
     X <- na.action(X)
+    X <- apply(X, 2, function (x) if (any(x == 0)) x + 1 else x)
     colnamsX <- colnames(X)
     dimnames(X) <- NULL
     ncatg <- apply(X, 2, function (x) length(unique(x)))
     n <- nrow(X)
     p <- ncol(X)
-    pats <- apply(X, 1, paste, collapse = "")
+    pats <- apply(X, 1, paste, collapse = "/")
     freqs <- table(pats)
     nfreqs <- length(freqs)
     obs <- as.vector(freqs)
-    X <- apply(cbind(names(freqs)), 1, function (x) { nx <- nchar(x); substring(x, 1:nx, 1:nx) } )
-    X <- as.numeric(t(X))
-    dim(X) <- c(nfreqs, p)
-    con <- list(iter.qN = 150, GHk = 15, method = "BFGS", verbose = getOption("verbose"), digits.abbrv = 6)
+    X <- unlist(strsplit(cbind(names(freqs)), "/"))
+    X <- matrix(as.numeric(X), nfreqs, p, TRUE)
+    con <- list(iter.qN = 150, GHk = 21, method = "BFGS", verbose = getOption("verbose"), digits.abbrv = 6)
     con[names(control)] <- control
     GH <- GHpoints(data ~ z1, con$GHk)
     Z <- GH$x[, 2]
